@@ -181,6 +181,14 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
     }
     debugLog () << "Actor::wget " << str << endl;
     if (uri.isLocalFile ()) {
+        for (Node *p = node->parentNode (); p; p = p->parentNode ()) {
+            Mrl *m = p->mrl ();
+            if (m && !m->src.isEmpty () && !URL (m->src).isLocalFile ()) {
+                errorLog () << "local acces denied\n";
+                ready ();
+                return true;
+            }
+        }
         File file (uri.path ());
         if (file.exists () && file.open (IO_ReadOnly)) {
             if (only_playlist) {
