@@ -69,6 +69,7 @@ static gboolean             has_video_codec;
 static gboolean cb_play (gpointer data);
 static gboolean cb_buffering (gpointer data);
 static gboolean cb_playing (gpointer data);
+static gboolean cb_paused (gpointer data);
 static gboolean cb_position (gpointer data);
 static gboolean cb_stop (gpointer data);
 static gboolean cb_eos (gpointer data);
@@ -296,8 +297,12 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
                         gstGetDuration ();
                         g_idle_add (cb_playing, NULL);
                     } else if (old_state >= GST_STATE_PAUSED &&
-                            new_state <= GST_STATE_READY)
+                            new_state <= GST_STATE_READY) {
                         g_idle_add (cb_stop, NULL);
+                    } else if (old_state > GST_STATE_PAUSED &&
+                            new_state == GST_STATE_PAUSED) {
+                        g_idle_add (cb_paused, NULL);
+                    }
                 } else if (old_state == GST_STATE_PAUSED &&
                         new_state >= GST_STATE_PLAYING) {
                     gchar *name = gst_object_get_name (GST_OBJECT (message->src));
@@ -559,6 +564,12 @@ static void pause () {
     if (gst_elm_play) {
         GstState state = GST_STATE (gst_elm_play) == GST_STATE_PLAYING ?
             GST_STATE_PAUSED : GST_STATE_PLAYING;
+
+        if (position_tag) {
+            g_source_remove (position_tag);
+            position_tag = 0;
+        }
+
         gst_element_set_state (gst_elm_play, state);
         gstPollForStateChange (gst_elm_play, state, GST_SECOND/2);
     }
@@ -706,8 +717,11 @@ static gboolean cb_play (gpointer data) {
 }
 
 static gboolean cb_buffering (gpointer data) {
+    GstState state;
     (void)data;
-    output ("\rCache fill: %d%", (long) data);
+    gst_element_get_state (gst_elm_play, &state, NULL, 0);
+    if (state != GST_STATE_PLAYING)
+        output ("\rCache fill: %d%", (long) data);
     return FALSE;
 }
 
@@ -718,19 +732,29 @@ static gboolean cb_playing (gpointer data) {
         if (!has_video_codec)
             output ("Video: no video\n");
         output ("\rA:0.0\rA:0.0");
-        position_tag = g_timeout_add (500, cb_position, NULL);
         if (seek_start > 0)
             seek (seek_start * 10);
+    } else {
+        output ("\rCache fill: 100%");
     }
+    if (!position_tag)
+        position_tag = g_timeout_add (500, cb_position, NULL);
+    return FALSE;
+}
+
+static gboolean cb_paused (gpointer data) {
+    (void)data;
+    output ("ID_PAUSED\n");
     return FALSE;
 }
 
 static gboolean cb_position (gpointer data) {
+    gboolean ret;
+    gint64 val = 0; /* usec */
     if (!position_tag) {
         fprintf(stderr, "cb_position  tag:%u\n", position_tag);
         return FALSE;
     }
-    gint64 val = 0; /* usec */
     if (gst_elm_play) {
         do {
             GstMessage * msg = gst_bus_poll (gst_bus, (GstMessageType) (GST_MESSAGE_STATE_CHANGED | GST_MESSAGE_ERROR | GST_MESSAGE_EOS | GST_MESSAGE_DURATION), GST_MSECOND * 10);
@@ -746,7 +770,10 @@ static gboolean cb_position (gpointer data) {
         }
     }
     output ("\rA:%0.1f", (val / (GST_MSECOND * 1000.0)));
-    return !!gst_elm_play;
+    ret = !!gst_elm_play;
+    if (!ret)
+        position_tag = 0;
+    return ret;
 }
 
 static gboolean cb_stop (gpointer data) {
