@@ -535,8 +535,6 @@ static String processForMimetype (Control *ctr, const String & mime)
         // hardcoded defaults FIXME
         if (NpPlayer::isFlashMimeType (mime))
             pname = "npp";
-        if (mime == "video/x-flv" || mime == "video/flv")
-            pname = ctr->mplayer ? "mplayer" : "npp";
     }
 #endif
     return pname;
