@@ -110,7 +110,7 @@ public:
 #ifdef __ARMEL__
     Process *npp;
 #endif
-    Process *downloader;
+    Downloader *downloader;
 
     NodePtr playlists;
     NodePtr recents;
