@@ -252,7 +252,8 @@ enum RoleType
     RoleDisplay,
     RoleChildDisplay,    // Mrl*
     RoleSizer,
-    RoleReceivers
+    RoleReceivers,
+    RolePlaylist
 };
 
 #define MsgUnhandled ((void *) 357L)
@@ -418,12 +419,6 @@ public:
     virtual PlayType playType ();
     bool isPlayable () { return playType () > play_type_none; }
     virtual bool isElementNode () const { return false; }
-    /**
-     * If this node should be visible to the user
-     */
-    virtual bool expose () const;
-    virtual String caption () const;
-    virtual void setCaption (const String &t);
     virtual String description () const;
     /**
      * If this node should be visible to the user
@@ -530,6 +525,8 @@ ITEM_AS_POINTER(KMPlayer::Node)
 
 const short id_node_document = 1;
 const short id_node_record_document = 2;
+const short id_node_download_document = 3;
+const short id_node_download = 4;
 const short id_node_text = 5;
 const short id_node_cdata = 6;
 
@@ -587,13 +584,11 @@ inline Node *findChildWithId (const Node *p, const short id) {
     return NULL;
 }
 
-class KMPLAYER_NO_EXPORT Title : public Element {
-protected:
-    Title (NodePtr & d, short id=0) : Element (d, id ) {}
-
+class KMPLAYER_NO_EXPORT PlaylistRole
+{
 public:
-    virtual String caption () const;
-    virtual void setCaption (const String &t);
+    String caption () const;
+    void setCaption (const String &t);
 
     String title;
 };
@@ -601,7 +596,7 @@ public:
 /**
  * Element representing a playable link, like URL to a movie or playlist.
  */
-class KMPLAYER_NO_EXPORT Mrl : public Title {
+class KMPLAYER_NO_EXPORT Mrl : public Element, public PlaylistRole {
 protected:
     Mrl (NodePtr & d, short id=0);
     Node *childFromTag (const String & tag);
@@ -614,10 +609,6 @@ public:
 
     ~Mrl ();
     PlayType playType ();
-    /*
-     * The original node (or this) having the URL, needed for playlist expansion
-     */
-    virtual Mrl * linkNode ();
     virtual Mrl * mrl ();
     String absolutePath ();
 
@@ -900,7 +891,6 @@ public:
     void accept (Visitor *v) { v->visit (this); }
     const char * nodeName () const { return "#text"; }
     String nodeValue () const;
-    bool expose () const;
 protected:
     String text;
 };
@@ -924,7 +914,6 @@ public:
     KDE_NO_CDTOR_EXPORT ~DarkNode () {}
     const char * nodeName () const { return (const char *) name; }
     Node *childFromTag (const String & tag);
-    virtual bool expose () const;
 protected:
     String name;
 };
@@ -952,7 +941,7 @@ public:
     KDE_NO_EXPORT const char * nodeName () const
         { return (const char *) node_name; }
     void closed ();
-    bool expose () const;
+    void *role (RoleType msg, void *content=NULL);
     /**
      * Will return false if this document has child nodes
      */
