@@ -1289,19 +1289,24 @@ static String genFileName (const String &str, bool skip_on_invalid) {
     return name;
 }
 
-bool KMPLAYER_NO_EXPORT Downloader::play (NodePtr mrl) {
-    Process::play (mrl);
-    if (!m_url.isEmpty ()) {
-        String name, title;
-        int pos = m_url.lastIndexOf (Char ('/'));
+void KMPLAYER_NO_EXPORT Downloader::createDownload (const String &url, const String &target_title) {
+    String name, err;
+    String title = target_title;
+    URL uri (url);
+
+    if (uri.isLocalFile ()) {
+        err = "Refuse to download a local file";
+    } else if (uri.protocol () != "http" &&
+            uri.protocol () != "https" &&
+            uri.protocol () != "ftp" &&
+            uri.protocol () != "sftp") {
+        err = String ("Cannot download from protocol ") + uri.protocol ();
+    } else {
+        int pos = url.lastIndexOf (Char ('/'));
         if (pos > 0)
-            name = genFileName ((const char *) m_url.mid (pos + 1), false);
-        PlaylistRole *title_role = (PlaylistRole*) mrl->role (RolePlaylist);
-        if (title_role) {
-            title = title_role->caption ();
-            if (name.isEmpty ())
-                name = title;
-        }
+            name = genFileName ((const char *) url.mid (pos + 1), false);
+        if (name.isEmpty ())
+            name = title;
         if (!name.isEmpty ()) {
             if (title.isEmpty ())
                 title = name;
@@ -1318,21 +1323,33 @@ bool KMPLAYER_NO_EXPORT Downloader::play (NodePtr mrl) {
                 NodePtr doc = m_notify->downloads ();
                 Element *n = new Download (doc, m_notify, fd);
                 doc->appendChild (n);
-                n->setAttribute (StringPool::attr_src, m_url);
+                n->setAttribute (StringPool::attr_src, url);
                 n->setAttribute (StringPool::attr_title, title);
                 n->setAttribute ("file", filename);
                 n->closed ();
                 n->begin ();
                 processNotify ()->updateDownloads ();
             } else {
-                String err ("Couldn't open file ");
+                err = "Couldn't open file ";
                 err += String (filename) + Char (' ');
                 err += strerror (errno);
-                processNotify ()->errorMsg (err);
             }
             app_store_save_directory (application, filename);
         }
     }
+    if (!err.isEmpty ())
+        processNotify ()->errorMsg (err);
+}
+
+bool KMPLAYER_NO_EXPORT Downloader::play (NodePtr mrl) {
+    Process::play (mrl);
+    if (!m_url.isEmpty ()) {
+        String title;
+        PlaylistRole *title_role = (PlaylistRole*) mrl->role (RolePlaylist);
+        if (title_role)
+            title = title_role->caption ();
+        createDownload (m_url, title);
+    }
     setState (NotRunning);
     return false;
 }
