@@ -972,6 +972,15 @@ void icConnection (ConIcConnection *conn, ConIcConnectionEvent *ev, gpointer) {
         g_slist_free (ic_connect_waiters);
         ic_connect_waiters = NULL;
         curlPerformMulti ();
+    } else if (CON_IC_STATUS_DISCONNECTED == ic_status) {
+        ConIcConnectionError err = con_ic_connection_event_get_error (ev);
+        if (CON_IC_CONNECTION_ERROR_NONE != err)
+            for (GSList *sl = ic_connect_waiters; sl; sl = sl->next) {
+                CurlGetJob *curl_job = (CurlGetJob *)ic_connect_waiters->data;
+                curl_job->error_code = 1;
+                curl_job->killed = true;
+            }
+        curlPerformMulti ();
     }
 }
 
@@ -1220,14 +1229,20 @@ void CurlGetJob::init (IOJob *job, off_t pos) {
     //    curl_easy_setopt (easy, CURLOPT_HTTPGET, true);
     if (CON_IC_STATUS_CONNECTED == ic_status || URL (url).isLocalFile ()) {
         start ();
+    } else if (ic_connect_request) {
+        ic_connect_waiters = g_slist_prepend (ic_connect_waiters, this);
     } else {
-        if (!ic_connect_request)
-            ic_connect_request = con_ic_connection_connect (con_ic_connection,
-                    CON_IC_CONNECT_FLAG_NONE);
-        if (ic_connect_request)
-            ic_connect_waiters = g_slist_prepend (ic_connect_waiters, this);
-        else
+        ic_connect_request = true;
+        if (con_ic_connection_connect (con_ic_connection,
+                CON_IC_CONNECT_FLAG_NONE)) {
+            if (!ic_connect_request)
+                start ();
+            else
+                ic_connect_waiters = g_slist_prepend (ic_connect_waiters, this);
+        } else {
+            ic_connect_request = false;
             job->kill (false);
+        }
     }
 }
 
